==> estateplat-common-1.2.4-20210923.070020-887-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxWwSqxxQlr.java <==
package cn.gtmap.estateplat.model.exchange.share;


import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;


/**
 * @author <a href="mailto:xuchao@gtmap.cn">xuchao</a>
 * @version 1.0
 * @description 外网申请权利人表
 */
@Table(name = "GX_WW_SQXX_QLR")
public class GxWwSqxxQlr implements Serializable {
    private static final long serialVersionUID = -7574042476035992642L;
    @Id
    private String qlrid;
    private String sqxxid;//GX_WW_SQXX id
    private String qlrmc;//权利人名称
    private String qlrsfzjzl;//权利人身份证件种类
    private String qlrzjh;//权利人证件号
    private String qlrtxdz;//权利人通讯地址
    private String qlrlx;//权利人类型
    private String qlbl;//权利比例
    private String qlrlxdh;//权利人联系电话
    private String dlrdh;//代理人电话
    private String dlrmc;//代理人名称
    private String fddbrdh;//法定代表人电话
    private String fddbrmc;//法定代表人名称
    private String qlryb;//权利人邮编
    private String dljgmc;//代理机构名称
    private String gyfs;//共有方式
    private String sfczr;//是否持证人
    private String qygyr;//其余共有人
    private String dlrsfzjzl;//代理人身份证件种类
    private String dlrzjh;//代理人证件号
    private int sxh;//顺序号
    private String czfsdm;//持证方式代码
    private String fwtc;//房屋套次
    private String hyzt;//婚姻状态
    private String qlrxz;//权利人性质
    private String qlrdlr;//权利人性质
    private String qlrdlrdh;//权利人代理人电话
    private String qlrdlrzjzl;//代理人证件种类
    private String qlrdlrzjh;//代理人证件号
    private String qlrfddbr;//权利人法定代表人
    private String qlrfddbrdh;//权利人法定代表人电话
    private String qlrfddbrzjzl;//权利人法定代表人证件种类
    private String qlrfddbrzjh;//权利人法定代表人证件号

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }

    public String getSqxxid() {
        return sqxxid;
    }

    public void setSqxxid(String sqxxid) {
        this.sqxxid = sqxxid;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getQlrsfzjzl() {
        return qlrsfzjzl;
    }

    public void setQlrsfzjzl(String qlrsfzjzl) {
        this.qlrsfzjzl = qlrsfzjzl;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getQlrtxdz() {
        return qlrtxdz;
    }

    public void setQlrtxdz(String qlrtxdz) {
        this.qlrtxdz = qlrtxdz;
    }

    public String getQlrlx() {
        return qlrlx;
    }

    public void setQlrlx(String qlrlx) {
        this.qlrlx = qlrlx;
    }

    public String getQlbl() {
        return qlbl;
    }

    public void setQlbl(String qlbl) {
        this.qlbl = qlbl;
    }

    public String getQlrlxdh() {
        return qlrlxdh;
    }

    public void setQlrlxdh(String qlrlxdh) {
        this.qlrlxdh = qlrlxdh;
    }

    public String getDlrdh() {
        return dlrdh;
    }

    public void setDlrdh(String dlrdh) {
        this.dlrdh = dlrdh;
    }

    public String getDlrmc() {
        return dlrmc;
    }

    public void setDlrmc(String dlrmc) {
        this.dlrmc = dlrmc;
    }

    public String getFddbrdh() {
        return fddbrdh;
    }

    public void setFddbrdh(String fddbrdh) {
        this.fddbrdh = fddbrdh;
    }

    public String getFddbrmc() {
        return fddbrmc;
    }

    public void setFddbrmc(String fddbrmc) {
        this.fddbrmc = fddbrmc;
    }

    public String getQlryb() {
        return qlryb;
    }

    public void setQlryb(String qlryb) {
        this.qlryb = qlryb;
    }

    public String getDljgmc() {
        return dljgmc;
    }

    public void setDljgmc(String dljgmc) {
        this.dljgmc = dljgmc;
    }

    public String getGyfs() {
        return gyfs;
    }

    public void setGyfs(String gyfs) {
        this.gyfs = gyfs;
    }

    public String getSfczr() {
        return sfczr;
    }

    public void setSfczr(String sfczr) {
        this.sfczr = sfczr;
    }

    public String getQygyr() {
        return qygyr;
    }

    public void setQygyr(String qygyr) {
        this.qygyr = qygyr;
    }

    public String getDlrsfzjzl() {
        return dlrsfzjzl;
    }

    public void setDlrsfzjzl(String dlrsfzjzl) {
        this.dlrsfzjzl = dlrsfzjzl;
    }

    public String getDlrzjh() {
        return dlrzjh;
    }

    public void setDlrzjh(String dlrzjh) {
        this.dlrzjh = dlrzjh;
    }

    public int getSxh() {
        return sxh;
    }

    public void setSxh(int sxh) {
        this.sxh = sxh;
    }

    public String getCzfsdm() {
        return czfsdm;
    }

    public void setCzfsdm(String czfsdm) {
        this.czfsdm = czfsdm;
    }

    public String getFwtc() {
        return fwtc;
    }

    public void setFwtc(String fwtc) {
        this.fwtc = fwtc;
    }

    public String getHyzt() {
        return hyzt;
    }

    public void setHyzt(String hyzt) {
        this.hyzt = hyzt;
    }

    public String getQlrxz() {
        return qlrxz;
    }

    public void setQlrxz(String qlrxz) {
        this.qlrxz = qlrxz;
    }

    public static long getSerialVersionUID() {
        return serialVersionUID;
    }

    public String getQlrdlr() {
        return qlrdlr;
    }

    public void setQlrdlr(String qlrdlr) {
        this.qlrdlr = qlrdlr;
    }

    public String getQlrdlrdh() {
        return qlrdlrdh;
    }

    public void setQlrdlrdh(String qlrdlrdh) {
        this.qlrdlrdh = qlrdlrdh;
    }

    public String getQlrdlrzjzl() {
        return qlrdlrzjzl;
    }

    public void setQlrdlrzjzl(String qlrdlrzjzl) {
        this.qlrdlrzjzl = qlrdlrzjzl;
    }

    public String getQlrdlrzjh() {
        return qlrdlrzjh;
    }

    public void setQlrdlrzjh(String qlrdlrzjh) {
        this.qlrdlrzjh = qlrdlrzjh;
    }

    public String getQlrfddbr() {
        return qlrfddbr;
    }

    public void setQlrfddbr(String qlrfddbr) {
        this.qlrfddbr = qlrfddbr;
    }

    public String getQlrfddbrdh() {
        return qlrfddbrdh;
    }

    public void setQlrfddbrdh(String qlrfddbrdh) {
        this.qlrfddbrdh = qlrfddbrdh;
    }

    public String getQlrfddbrzjzl() {
        return qlrfddbrzjzl;
    }

    public void setQlrfddbrzjzl(String qlrfddbrzjzl) {
        this.qlrfddbrzjzl = qlrfddbrzjzl;
    }

    public String getQlrfddbrzjh() {
        return qlrfddbrzjh;
    }

    public void setQlrfddbrzjh(String qlrfddbrzjh) {
        this.qlrfddbrzjh = qlrfddbrzjh;
    }
}

==> estateplat-common-1.2.4-20221115.082418-1119-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxWwSqxxQlr.java <==
package cn.gtmap.estateplat.model.exchange.share;


import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;


/**
 * @author <a href="mailto:xuchao@gtmap.cn">xuchao</a>
 * @version 1.0
 * @description 外网申请权利人表
 */
@Table(name = "GX_WW_SQXX_QLR")
public class GxWwSqxxQlr implements Serializable {
    private static final long serialVersionUID = -7574042476035992642L;
    @Id
    private String qlrid;
    private String sqxxid;//GX_WW_SQXX id
    private String qlrmc;//权利人名称
    private String qlrsfzjzl;//权利人身份证件种类
    private String qlrzjh;//权利人证件号
    private String qlrtxdz;//权利人通讯地址
    private String qlrlx;//权利人类型
    private String qlbl;//权利比例
    private String qlrlxdh;//权利人联系电话
    private String dlrdh;//代理人电话
    private String dlrmc;//代理人名称
    private String fddbrdh;//法定代表人电话
    private String fddbrmc;//法定代表人名称
    private String qlryb;//权利人邮编
    private String dljgmc;//代理机构名称
    private String gyfs;//共有方式
    private String sfczr;//是否持证人
    private String qygyr;//其余共有人
    private String dlrsfzjzl;//代理人身份证件种类
    private String dlrzjh;//代理人证件号
    private int sxh;//顺序号
    private String czfsdm;//持证方式代码
    private String fwtc;//房屋套次
    private String hyzt;//婚姻状态
    private String qlrxz;//权利人性质
    private String qlrdlr;//权利人代理人
    private String qlrdlrdh;//权利人代理人电话
    private String qlrdlrzjzl;//代理人证件种类
    private String qlrdlrzjh;//代理人证件号
    private String qlrfddbr;//权利人法定代表人
    private String qlrfddbrdh;//权利人法定代表人电话
    private String qlrfddbrzjzl;//权利人法定代表人证件种类
    private String qlrfddbrzjh;//权利人法定代表人证件号

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }

    public String getSqxxid() {
        return sqxxid;
    }

    public void setSqxxid(String sqxxid) {
        this.sqxxid = sqxxid;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getQlrsfzjzl() {
        return qlrsfzjzl;
    }

    public void setQlrsfzjzl(String qlrsfzjzl) {
        this.qlrsfzjzl = qlrsfzjzl;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getQlrtxdz() {
        return qlrtxdz;
    }

    public void setQlrtxdz(String qlrtxdz) {
        this.qlrtxdz = qlrtxdz;
    }

    public String getQlrlx() {
        return qlrlx;
    }

    public void setQlrlx(String qlrlx) {
        this.qlrlx = qlrlx;
    }

    public String getQlbl() {
        return qlbl;
    }

    public void setQlbl(String qlbl) {
        this.qlbl = qlbl;
    }

    public String getQlrlxdh() {
        return qlrlxdh;
    }

    public void setQlrlxdh(String qlrlxdh) {
        this.qlrlxdh = qlrlxdh;
    }

    public String getDlrdh() {
        return dlrdh;
    }

    public void setDlrdh(String dlrdh) {
        this.dlrdh = dlrdh;
    }

    public String getDlrmc() {
        return dlrmc;
    }

    public void setDlrmc(String dlrmc) {
        this.dlrmc = dlrmc;
    }

    public String getFddbrdh() {
        return fddbrdh;
    }

    public void setFddbrdh(String fddbrdh) {
        this.fddbrdh = fddbrdh;
    }

    public String getFddbrmc() {
        return fddbrmc;
    }

    public void setFddbrmc(String fddbrmc) {
        this.fddbrmc = fddbrmc;
    }

    public String getQlryb() {
        return qlryb;
    }

    public void setQlryb(String qlryb) {
        this.qlryb = qlryb;
    }

    public String getDljgmc() {
        return dljgmc;
    }

    public void setDljgmc(String dljgmc) {
        this.dljgmc = dljgmc;
    }

    public String getGyfs() {
        return gyfs;
    }

    public void setGyfs(String gyfs) {
        this.gyfs = gyfs;
    }

    public String getSfczr() {
        return sfczr;
    }

    public void setSfczr(String sfczr) {
        this.sfczr = sfczr;
    }

    public String getQygyr() {
        return qygyr;
    }

    public void setQygyr(String qygyr) {
        this.qygyr = qygyr;
    }

    public String getDlrsfzjzl() {
        return dlrsfzjzl;
    }

    public void setDlrsfzjzl(String dlrsfzjzl) {
        this.dlrsfzjzl = dlrsfzjzl;
    }

    public String getDlrzjh() {
        return dlrzjh;
    }

    public void setDlrzjh(String dlrzjh) {
        this.dlrzjh = dlrzjh;
    }

    public int getSxh() {
        return sxh;
    }

    public void setSxh(int sxh) {
        this.sxh = sxh;
    }

    public String getCzfsdm() {
        return czfsdm;
    }

    public void setCzfsdm(String czfsdm) {
        this.czfsdm = czfsdm;
    }

    public String getFwtc() {
        return fwtc;
    }

    public void setFwtc(String fwtc) {
        this.fwtc = fwtc;
    }

    public String getHyzt() {
        return hyzt;
    }

    public void setHyzt(String hyzt) {
        this.hyzt = hyzt;
    }

    public String getQlrxz() {
        return qlrxz;
    }

    public void setQlrxz(String qlrxz) {
        this.qlrxz = qlrxz;
    }

    public static long getSerialVersionUID() {
        return serialVersionUID;
    }

    public String getQlrdlr() {
        return qlrdlr;
    }

    public void setQlrdlr(String qlrdlr) {
        this.qlrdlr = qlrdlr;
    }

    public String getQlrdlrdh() {
        return qlrdlrdh;
    }

    public void setQlrdlrdh(String qlrdlrdh) {
        this.qlrdlrdh = qlrdlrdh;
    }

    public String getQlrdlrzjzl() {
        return qlrdlrzjzl;
    }

    public void setQlrdlrzjzl(String qlrdlrzjzl) {
        this.qlrdlrzjzl = qlrdlrzjzl;
    }

    public String getQlrdlrzjh() {
        return qlrdlrzjh;
    }

    public void setQlrdlrzjh(String qlrdlrzjh) {
        this.qlrdlrzjh = qlrdlrzjh;
    }

    public String getQlrfddbr() {
        return qlrfddbr;
    }

    public void setQlrfddbr(String qlrfddbr) {
        this.qlrfddbr = qlrfddbr;
    }

    public String getQlrfddbrdh() {
        return qlrfddbrdh;
    }

    public void setQlrfddbrdh(String qlrfddbrdh) {
        this.qlrfddbrdh = qlrfddbrdh;
    }

    public String getQlrfddbrzjzl() {
        return qlrfddbrzjzl;
    }

    public void setQlrfddbrzjzl(String qlrfddbrzjzl) {
        this.qlrfddbrzjzl = qlrfddbrzjzl;
    }

    public String getQlrfddbrzjh() {
        return qlrfddbrzjh;
    }

    public void setQlrfddbrzjh(String qlrfddbrzjh) {
        this.qlrfddbrzjh = qlrfddbrzjh;
    }
}
